/*
 * Copyright © 2021-2022 Harsh Shandilya.
 * Use of this source code is governed by an MIT-style
 * license that can be found in the LICENSE file or at
 * https://opensource.org/licenses/MIT.
 */
@file:Suppress("DSL_SCOPE_VIOLATION", "UnstableApiUsage")

import org.gradle.kotlin.dsl.withType
import org.jetbrains.kotlin.gradle.tasks.KotlinCompile

plugins {
  id("dev.msfjarvis.claw.kotlin-android")
  id("dev.msfjarvis.claw.android-library")
  alias(libs.plugins.anvil)
  alias(libs.plugins.whetstone)
}

anvil { generateDaggerFactories.set(true) }

androidComponents { beforeVariants { it.enableUnitTest = false } }

tasks.withType<KotlinCompile>().configureEach {
  kotlinOptions {
    freeCompilerArgs =
      freeCompilerArgs +
        listOf(
          "-P",
          "plugin:androidx.compose.compiler.plugins.kotlin:reportsDestination=" +
            rootProject.buildDir.absolutePath +
            "/compose_metrics/",
          "-P",
          "plugin:androidx.compose.compiler.plugins.kotlin:metricsDestination=" +
            rootProject.buildDir.absolutePath +
            "/compose_metrics/",
        )
  }
}

dependencies {
  implementation(platform(libs.androidx.compose.bom))
  api(libs.napier)
  implementation(projects.core)
  implementation(projects.database)
  implementation(projects.model)
  implementation(libs.accompanist.flowlayout)
  implementation(libs.androidx.browser)
  implementation(libs.androidx.compose.animation)
  implementation(libs.androidx.compose.foundation)
  implementation(libs.androidx.compose.material3)
  implementation(libs.androidx.compose.runtime)
  implementation(libs.androidx.compose.ui.text)
  implementation(libs.androidx.compose.ui.tooling)
  implementation(libs.androidx.compose.ui.tooling.preview)
  implementation(libs.coil.compose)
  implementation(libs.compose.richtext.markdown)
  implementation(libs.compose.richtext.material3)
  implementation(libs.compose.richtext.ui)
  implementation(libs.kotlinx.coroutines.core)
  testImplementation(kotlin("test-junit"))
  testImplementation(libs.testparameterinjector)
}

android {
  buildFeatures {
    androidResources = true
    compose = true
  }
  composeOptions {
    useLiveLiterals = false
    kotlinCompilerExtensionVersion = libs.versions.composeCompiler.get()
  }
  namespace = "dev.msfjarvis.claw.common"
}
